/**
 * Admin Settings JavaScript.
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/admin
 * @author     WPEka Club <support@wpeka.com>
 */
(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */
	$(function() {

        Vue.use(VueFormWizard);
        Vue.use(window.vuelidate.default);
        const { required, email, url } = window.validators;

        var app = new Vue({
            el: '#wpadcenter-wizard',
            data:{
				modelAdzone:{
                    adzones:[],
                    adzone_templates:[
                        { id: "468x60", name: "IAB Full Banner (468 x 60)" },
                        { id: "120x600", name: "IAB Skyscraper (120 x 600)" },
                        { id: "160x600", name: "IAB Wide Skyscraper (160 x 600)" },
                        { id: "728x90", name: "IAB Leaderboard (728 x 90)" },
                        { id: "180x150", name: "IAB Rectangle (180 x 150)" },
                        { id: "300x250", name: "IAB Medium Rectangle (300 x 250)" },
                        { id: "120x90", name: "IAB Button 1 (120 x 90)" },
                        { id: "120x60", name: "IAB Button 2 (120 x 60)" },
                        { id: "125x125", name: "IAB Square Button (125 x 125)" },
                        { id: "0", name: "Custom" },
                    ],
                    transition_effects:[
                        { id: "none", name: "None" },
                        { id: "fade", name: "Fade" },
                        { id: "fadeout", name: "Fade Out" },
                        { id: "scrollHorz", name: "Scroll Right to Left" },
                        { id: "scrollHorzReverse", name: "Scroll Left to Right" },
                        { id: "scrollVert", name: "Scroll Top to Bottom" },
                        { id: "scrollVertReverse", name: "Scroll Bottom to Top" }
                    ],
                    adzone: '',
                    adzone_name:'',
					adzone_description:'',
                    adzone_template:'468x60',
                    adzone_custom_width:'600',
                    adzone_custom_height:'400',
                    auto_refresh:false,
                    transition_effect:'none',
                    transition_speed:'1000',
                    transition_delay:'1000',
				},
                modelAdvertiser:{
				    advertisers:[],
                    advertiser:'',
                    advertiser_name:'',
                    advertiser_email:'',
                },
                modelCampaign:{
                    campaigns:[],
                    cam_advertisers:[],
                    campaign:'',
                    campaign_name:'',
                    campaign_start:'',
                    campaign_end:'',
                    campaign_advertiser:'',
                },
                modelAds:{
				    file: '',
				    ad_advertisers: [],
                    ad_campaigns:[],
                    ad_adzones:[],
                    ad_types:[
                        { id: "image", name: "Banner Image" },
                        { id: "external_image_link", name: "External Image Link" },
                        { id: "ad_code", name: "Ad Code" },
                        { id: "adsense_code", name: "Google Adsense" },
                    ],
                    ad_advertiser:'',
                    ad_campaign:'',
                    ad_adzone:'',
                    ad:'',
                    ad_name:'',
                    ad_link_url:'',
                    ad_link_target:true,
                    ad_link_nofollow:true,
                    ad_type:'image',
                    ad_image:'',
                    ad_image_file:'Upload Image',
                    ad_image_link_url:'',
                    ad_code:'',
                    google_adsense_code: ''
                },
                submitted:false,
            },
            validations:{
                modelAdzone:{
                    adzone_name: {required},
                    adzone_custom_width: {required},
                    adzone_custom_height: {required}
                },
                modelAdvertiser: {
                    advertiser_name: {required},
                    advertiser_email: {required,email}
                },
                modelCampaign: {
                    campaign_name: {required},
                    campaign_advertiser: {required},
                    campaign_start: {required},
                },
                modelAds: {
                    ad_name: {required},
                    ad_image:{required},
                    ad_image_link_url: {required, url},
                    ad_code:{required},
                    ad_advertiser:{required},
                    ad_campaign:{required},
                    ad_adzone:{required}
                }
            },
            methods: {
                loadAdCode: function loadAdCode(e){
                    e.preventDefault();
                    let button = $(e.target);
                    let spinner = button.parent().find('.spinner');
                    spinner.addClass('is-active');
                    var nonce  = AdsenseGAPI.nonce;
                    $.ajax({
                        url:ajaxurl,
                        type:'POST',
                        data : {
                            action: 'adsense_load_adcode',
                            adunit:button.attr('data-unitid'),
                            _wpnonce:nonce
                        },
                        success:function(data){
                            spinner.removeClass('is-active');
                            button.text('Loaded');
                            app.modelAds.google_adsense_code = data.message;

                        },
                        error:function(){

                        }

                    })
                },

                campaignAdvertiserChange: function(event) {
                    if(event) {
                        app.modelAdvertiser.advertiser = event.target.value;
                    }
                },
                adAdvertiserChange: function(event) {
                    app.modelAdvertiser.advertiser = event.target.value;
                    app.modelAds.ad_campaign = '';
                    var request_param = {request:"get_ad_campaigns", id:event.target.value};
                    app.getWizardData(ajax_url, request_param);
                },
                adCampaignChange: function(event) {
                    if(event) {
                        app.modelCampaign.campaign = event.target.value;
                    }
                },
                adAdzoneChange: function(event) {
                    if(event) {
                        app.modelAdzone.adzone = event.target.value;
                    }
                },
                uploadAdImage: function(event) {
                    event.preventDefault();
                    var mediaUploader;
                    if (mediaUploader) {
                        mediaUploader.open();
                        return;
                    }
                    mediaUploader = wp.media.frames.file_frame = wp.media({
                        title: 'Choose Image',
                        button: {
                            text: 'Choose Image'
                        }, multiple: false,
                        library: {
                            type: [ 'image' ]
                        }
                    });
                    mediaUploader.on('select', function() {
                        var attachment = mediaUploader.state().get('selection').first().toJSON();
                        if(attachment) {
                            app.modelAds.ad_image = attachment.id;
                            $('#ad_image_filename').html(attachment.filename);
                        }
                    });
                    mediaUploader.open();
                },
                onComplete: function(){
                    setTimeout(function(){
                        window.location.href = ajax_url.admin+'post.php?post='+app.modelAds.ad+'&action=edit';
                    },3000);
                },
                onChange: function(prevTab, nextTab) {
                    if(nextTab == '0') {
                        app.submitted = false;
                        var request_param = {request:"get_adzones", id:"0"};
                        this.getWizardData(ajax_url, request_param);
                    }
                    if(nextTab == '1') {
                        app.submitted = false;
                        var request_param = {request:"get_advertisers", id:"0"};
                        this.getWizardData(ajax_url, request_param);
                    }
                    if(nextTab == '2') {
                        app.submitted = false;
                        if(app.modelAdvertiser.advertiser != '0') {
                            var request_param = {request:"get_campaigns", id:"0"};
                            request_param.id = app.modelAdvertiser.advertiser;
                            app.modelCampaign.campaign_advertiser = app.modelAdvertiser.advertiser;
                            this.getWizardData(ajax_url, request_param);
                            var request_param = {request:"get_campaign_advertisers", id:"0"};
                            this.getWizardData(ajax_url, request_param);
                        }
                    }
                    if(nextTab == '3') {
                        app.submitted = false;
                        var request_param = {request:"get_ad_adzones", id:"0"};
                        this.getWizardData(ajax_url, request_param);
                        var request_param = {request:"get_ad_advertisers", id:"0"};
                        this.getWizardData(ajax_url, request_param);
                        if(app.modelAdzone.adzone) {
                            app.modelAds.ad_adzone = app.modelAdzone.adzone;
                        }
                        if(app.modelAdvertiser.advertiser) {
                            app.modelAds.ad_advertiser = app.modelAdvertiser.advertiser;
                        }
                        if(app.modelCampaign.campaign != '0') {
                            var request_param = {request:"get_ad_campaigns", id:"0"};
                            if(app.modelAdvertiser.advertiser) {
                                request_param.id = app.modelAdvertiser.advertiser;
                            }
                            this.getWizardData(ajax_url, request_param);
                            app.modelAds.ad_campaign = app.modelCampaign.campaign;
                        }
                    }
                },
                validateAdzoneTab: function(){
                    app.submitted = true;
                    if(app.modelAdzone.adzone && app.modelAdzone.adzone == '0') {
                        if(app.$v.modelAdzone.adzone_name.$invalid || app.$v.modelAdzone.adzone_custom_width.$invalid || app.$v.modelAdzone.adzone_custom_height.$invalid) {
                            return false;
                        }
                        var request_param = {request:"save_adzone", data:app.modelAdzone};
                        this.saveWizardData(ajax_url, request_param);
                    }
                    return true;
                },
                validateAdvertiserTab: function(){
                    app.submitted = true;
                    if(app.modelAdvertiser.advertiser && app.modelAdvertiser.advertiser == '0') {
                        if(app.$v.modelAdvertiser.advertiser_name.$invalid || app.$v.modelAdvertiser.advertiser_email.$invalid) {
                            return false;
                        }
                        var request_param = {request:"save_advertiser", data:app.modelAdvertiser};
                        this.saveWizardData(ajax_url, request_param);
                    }
                    return true;
                },
                validateCampaignTab: function(){
                    app.submitted = true;
                    if(app.modelCampaign.campaign && app.modelCampaign.campaign == '0') {
                        if(app.$v.modelCampaign.campaign_name.$invalid || app.$v.modelCampaign.campaign_advertiser.$invalid || app.$v.modelCampaign.campaign_start.$invalid) {
                            return false;
                        }
                        var request_param = {request:"save_campaign", data:app.modelCampaign};
                        this.saveWizardData(ajax_url, request_param);
                    }
                    return true;
                },
                validateAdTab: function(){
                    app.submitted = true;
                    if( app.$v.modelAds.ad_name.$invalid
                        || ( app.modelAds.ad_type === 'image' && app.$v.modelAds.ad_image.$invalid )
                        || (app.modelAds.ad_type === 'external_image_link' && app.$v.modelAds.ad_image_link_url.$invalid)
                        || (app.modelAds.ad_type === 'ad_code' && app.$v.modelAds.ad_code.$invalid)
                        || (app.modelAds.ad_type === 'adsense_code' && app.modelAds.google_adsense_code=='')
                        || app.$v.modelAds.ad_advertiser.$invalid
                        || app.$v.modelAds.ad_campaign.$invalid
                        || app.$v.modelAds.ad_adzone.$invalid) {
                        return false;
                    }
                    var request_param = {request:"save_ad", data:app.modelAds};
                    this.saveWizardData(ajax_url, request_param);
                    return true;
                },
                saveWizardData: function(ajax_url, request_param) {
                   var request = {
                       action: "save_wizard_data",
                       request: request_param.request,
                       data: request_param.data,
                       security: ajax_url.security,
                   };
                    $.post(ajax_url.url, request).always(function(response){
                        response = JSON.parse(response);
                        if(response.success && response.id != "0") {
                            if(request_param.request == 'save_adzone') {
                                app.modelAdzone.adzone = response.id;
                            }
                            if(request_param.request == 'save_advertiser') {
                                app.modelAdvertiser.advertiser = response.id;
                                var request_param1 = {request:"get_campaigns", id:"0"};
                                request_param1.id = app.modelAdvertiser.advertiser;
                                app.modelCampaign.campaign_advertiser = app.modelAdvertiser.advertiser;
                                app.getWizardData(ajax_url, request_param1);
                                var request_param2 = {request:"get_campaign_advertisers", id:"0"};
                                app.getWizardData(ajax_url, request_param2);
                            }
                            if(request_param.request == 'save_campaign') {
                                app.modelCampaign.campaign = response.id;
                                app.modelAdvertiser.advertiser = request_param.data.campaign_advertiser;
                                var request_param1 = {request:"get_ad_campaigns", id:"0"};
                                if(app.modelAdvertiser.advertiser) {
                                    request_param1.id = app.modelAdvertiser.advertiser;
                                }
                                app.getWizardData(ajax_url, request_param1);
                                app.modelAds.ad_campaign = app.modelCampaign.campaign;
                            }
                            if(request_param.request == 'save_ad') {
                                app.modelAds.ad = response.id;
                            }
                        }
                    });
                },
                getWizardData: function(ajax_url, request_param) {
                    var request = {
                        action:  "get_wizard_data",
                        request: request_param.request,
                        id: request_param.id,
                        security: ajax_url.security,
                    };
                    $.post(ajax_url.url, request).always(function(response){
                        if(request_param.request == 'get_adzones') {
                            app.modelAdzone.adzones = JSON.parse(response);
                        }
                        if(request_param.request == 'get_advertisers') {
                            app.modelAdvertiser.advertisers = JSON.parse(response);
                        }
                        if(request_param.request == 'get_campaigns') {
                            app.modelCampaign.campaigns = JSON.parse(response);
                        }
                        if(request_param.request == 'get_campaign_advertisers') {
                            app.modelCampaign.cam_advertisers = JSON.parse(response);
                        }
                        if(request_param.request == 'get_ad_adzones') {
                            app.modelAds.ad_adzones = JSON.parse(response);
                        }
                        if(request_param.request == 'get_ad_advertisers') {
                            app.modelAds.ad_advertisers = JSON.parse(response);
                        }
                        if(request_param.request == 'get_ad_campaigns') {
                            app.modelAds.ad_campaigns = JSON.parse(response);
                        }
                    });
                }
            },
            created: function() {
                var request_param = {request:"get_adzones", id:"0"};
                this.getWizardData(ajax_url, request_param);
            },
        });

	});
})( jQuery );