<?php
/**
 * Provide a admin area view for the scripts tab.
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://club.wpeka.com
 * @since      1.0.1
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/admin/views
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

$data_obj = \Wpeka\Adcenter\Wpadcenter_Adsense::get_instance();

$data = $data_obj->get_saved_accounts();

$nonce = wp_create_nonce( 'wpeka-google-adsense' );

$auth_url = \Wpeka\Adcenter\Wpadcenter_Google_Api::get_auth_url();


?>
<div class="wpadcenter-tab-content" data-id="<?php echo esc_attr( $target_id ); ?>">


	<table class="form-table">
		<?php do_action( 'wpadcenter_before_adsense_settings' ); ?>
		<?php if ( ! empty( $data['accounts'] ) && is_array( $data['accounts'] ) ) : ?>

			<tr valign="top">
				<th scope="row">
					<label><?php esc_html_e( 'Google Adsense Account', 'wpadcenter' ); ?></label>
				</th>
				<td>
					<select name="gadsense_account_id">
						<?php foreach ( $data['accounts'] as $key => $account ) { ?>
							<option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $key ); ?></option>
						<?php } ?>
					</select>
				</td>
			</tr>



		<?php else : ?>

			<tr valign="top">
				<th scope="row"><label for="enable_ads_txt_field"><?php esc_attr_e( 'AdSense', 'wpadcenter' ); ?></label>
				</th>
				<td>
					<button id="init-gauth" class="button-primary"><?php esc_html_e( 'Connect to AdSense', 'wpadcenter' ); ?></button>
					<p class="description">
						<?php
						esc_html_e('This will open another window. Please allow access to your AdSense account. Copy the text you get at the end and come back here.', 'wpadcenter');
						?>
					</p>
				</td>
			</tr>
			<tr valign="top">
				<th><?php esc_html_e( 'Token', 'wpadcenter' ); ?></th>
				<td>
					<input type="text" class="widefat" id="mapi-code" value="" />
					<p class="description"><?php esc_html_e( 'You will get token after you click on Connect to AdSense', 'wpadcenter' ); ?></p>
					<div class="submit">
						<button id="mapi-confirm-code" class="button-primary">
							<?php esc_html_e( 'Submit Token', 'wpadcenter' ); ?>
						</button>
						<span class="spinner"></span>
					</div>
				</td>
			</tr>
		<?php endif; ?>
		<?php do_action( 'wpadcenter_after_adsense_settings' ); ?>
	</table>

</div>
<script type="text/javascript">
	if ('undefined' == typeof window.AdsenseGAPI) {
		AdsenseGAPI = {};
	}
	AdsenseGAPI.nonce = '<?php echo esc_html( $nonce ); ?>';
	AdsenseGAPI.oAuth2 = '<?php echo $auth_url; // phpcs:ignore WordPress.Security.EscapeOutput ?>';
</script>
