<?php
/**
 * Provide a admin area view for the getting started wizard page.
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://club.wpeka.com
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/admin/views
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
?>
<div class="clear"></div>
<div class="wrap">
	<h2></h2>
<div id="wpadcenter-wizard" class="wpadcenter-getting-started-wizard">
	<form-wizard enctype="multipart/form-data" @on-complete="onComplete" title="" subtitle="" color="#007cba" error-color="#a94442" @on-change="onChange" back-button-text="Back" next-button-text="Continue" finish-button-text="Create">
		<h2 slot="title"><img src="<?php echo esc_url_raw( WPADCENTER_PLUGIN_URL ) . 'admin/images/wpadcenter-logo.png'; ?>" alt="WPAdCenter Logo"/></h2>
		<tab-content title="Ad Zone" :before-change="validateAdzoneTab">
				<fieldset v-model="modelAdzone">
					<div class="form-group">
						<label for="adzone" class="form-label"><?php esc_html_e( 'Adzone', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="adzone" class="form-control" name="adzone" v-model="modelAdzone.adzone">
								<option value="" selected><?php esc_html_e( 'Select Adzone', 'wpadcenter' ); ?></option>
								<option v-for="adzone in modelAdzone.adzones" :value="adzone.id">{{adzone.name}}
								</option>
							</select>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0'">
						<label for="adzone_name" class="form-label"><?php esc_html_e( 'Ad Zone Name', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="adzone_name" class="form-control" type="text" name="adzone_name" v-model="modelAdzone.adzone_name"/>
							<span class="has-error" v-if="submitted && !$v.modelAdzone.adzone_name.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0'">
						<label for="adzone_description" class="form-label"><?php esc_html_e( 'Description', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<textarea id="adzone_description" class="form-control" name="adzone_description" v-model="modelAdzone.adzone_description" rows="5"></textarea>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0'">
						<label for="adzone_template" class="form-label"><?php esc_html_e( 'Template', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="adzone_template" class="form-control" name="adzone_template" v-model="modelAdzone.adzone_template">
								<option v-for="adzone_template in modelAdzone.adzone_templates" :value="adzone_template.id">{{adzone_template.name}}</option>
							</select>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0' && modelAdzone.adzone_template==='0'">
						<label for="adzone_custom_width" class="form-label"><?php esc_html_e( 'Width (in px)', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="adzone_custom_width" class="form-control" type="number" step="1" name="adzone_custom_width" v-model="modelAdzone.adzone_custom_width"/>
							<span class="has-error" v-if="submitted && !$v.modelAdzone.adzone_custom_width.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0' && modelAdzone.adzone_template==='0'">
						<label for="adzone_custom_height" class="form-label"><?php esc_html_e( 'Height (in px)', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="adzone_custom_height" class="form-control" type="number" step="1" name="adzone_custom_height" v-model="modelAdzone.adzone_custom_height"/>
							<span class="has-error" v-if="submitted && !$v.modelAdzone.adzone_custom_height.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0'">
						<label class="form-label"><?php esc_html_e( 'Auto Refresh', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<div class="form-radio">
								<label for="auto_refresh_true"><input type="radio" id="auto_refresh_true" name="auto_refresh" value="true" v-model="modelAdzone.auto_refresh">Enable</label>
								<label for="auto_refresh_false"><input type="radio" id="auto_refresh_false" name="auto_refresh" value="false" v-model="modelAdzone.auto_refresh" checked>Disable</label>
							</div>
							<span class="form-help"><?php esc_html_e( 'Auto refresh all ads in this adzone.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone=='0' && modelAdzone.auto_refresh==='true'">
						<label for="transition_effect" class="form-label"><?php esc_html_e( 'Transition Effect', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="transition_effect" class="form-control" name="transition_effect" v-model="modelAdzone.transition_effect">
								<option v-for="transition_effect in modelAdzone.transition_effects" :value="transition_effect.id">{{transition_effect.name}}</option>
							</select>
							<span class="form-help"><?php esc_html_e( 'Transition effect for ads, if Auto Refresh is enabled.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0' && modelAdzone.auto_refresh==='true'">
						<label for="transition_speed" class="form-label"><?php esc_html_e( 'Transition Speed', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="transition_speed" class="form-control" type="number" step="100" min="500" name="transition_speed" v-model="modelAdzone.transition_speed"/>
							<span class="form-help"><?php esc_html_e( 'Speed in milliseconds for ad transitions, if Auto Refresh is enabled.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAdzone.adzone==='0' && modelAdzone.auto_refresh==='true'">
						<label for="transition_delay" class="form-label"><?php esc_html_e( 'Transition Delay', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="transition_delay" class="form-control" type="number" step="100" min="500" name="transition_delay" v-model="modelAdzone.transition_delay"/>
							<span class="form-help"><?php esc_html_e( 'Delay in milliseconds between ad transitions, if Auto Refresh is enabled.', 'wpadcenter' ); ?></span>
						</div>
					</div>
				</fieldset>
		</tab-content>
		<tab-content title="Advertiser" :before-change="validateAdvertiserTab">
			<fieldset v-model="modelAdvertiser">
				<div class="form-group">
					<label for="advertiser" class="form-label"><?php esc_html_e( 'Advertiser', 'wpadcenter' ); ?></label>
					<div class="form-content">
						<select id="advertiser" class="form-control" name="advertiser" v-model="modelAdvertiser.advertiser">
							<option value="" selected><?php esc_html_e( 'Select Advertiser', 'wpadcenter' ); ?></option>
							<option v-for="advertiser in modelAdvertiser.advertisers" :value="advertiser.id">{{advertiser.name}}</option>
						</select>
					</div>
				</div>
				<div class="form-group" v-show="modelAdvertiser.advertiser==='0'">
					<label for="advertiser_name" class="form-label"><?php esc_html_e( 'Advertiser Name', 'wpadcenter' ); ?></label>
					<div class="form-content">
						<input id="advertiser_name" class="form-control" type="text" name="advertiser_name" v-model="modelAdvertiser.advertiser_name"/>
						<span class="has-error" v-if="submitted && !$v.modelAdvertiser.advertiser_name.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
					</div>
				</div>
				<div class="form-group" v-show="modelAdvertiser.advertiser==='0'">
					<label for="advertiser_email" class="form-label"><?php esc_html_e( 'Advertiser Email', 'wpadcenter' ); ?></label>
					<div class="form-content">
						<input id="advertiser_email" class="form-control" type="email" name="advertiser_email" v-model="modelAdvertiser.advertiser_email"/>
						<span class="has-error" v-if="submitted && !$v.modelAdvertiser.advertiser_email.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						<span class="has-error" v-if="submitted && !$v.modelAdvertiser.advertiser_email.email"><?php esc_html_e( 'Invalid email!', 'wpadcenter' ); ?></span>
					</div>
				</div>
			</fieldset>
		</tab-content>
		<tab-content title="Campaign" :before-change="validateCampaignTab">
				<fieldset v-model="modelCampaign">
					<div class="form-group">
						<label for="campaign" class="form-label"><?php esc_html_e( 'Campaign', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="campaign" class="form-control" name="campaign" v-model="modelCampaign.campaign">
								<option value="" selected><?php esc_html_e( 'Select Campaign', 'wpadcenter' ); ?></option>
								<option v-for="campaign in modelCampaign.campaigns" :value="campaign.id">{{campaign.name}}</option>
							</select>
						</div>
					</div>
					<div class="form-group" v-show="modelCampaign.campaign==='0'">
						<label for="campaign_name" class="form-label"><?php esc_html_e( 'Campaign Name', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="campaign_name" class="form-control" type="text" name="campaign_name" v-model="modelCampaign.campaign_name"/>
							<span class="has-error" v-if="submitted && !$v.modelCampaign.campaign_name.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelCampaign.campaign==='0'">
						<label for="campaign_advertiser" class="form-label"><?php esc_html_e( 'Advertiser', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="campaign_advertiser" class="form-control" name="campaign_advertiser" v-model="modelCampaign.campaign_advertiser" v-on:change="campaignAdvertiserChange">
								<option v-for="cam_advertiser in modelCampaign.cam_advertisers" :value="cam_advertiser.id">{{cam_advertiser.name}}</option>
							</select>
							<span class="has-error" v-if="submitted && !$v.modelCampaign.campaign_advertiser.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelCampaign.campaign==='0'">
						<label for="campaign_start" class="form-label"><?php esc_html_e( 'Start Date', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="campaign_start" class="form-control" type="date" name="campaign_start" v-model="modelCampaign.campaign_start"/>
							<span class="has-error" v-if="submitted && !$v.modelCampaign.campaign_start.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelCampaign.campaign==='0'">
						<label for="campaign_end" class="form-label"><?php esc_html_e( 'End Date', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="campaign_end" class="form-control" type="date" name="campaign_end" v-model="modelCampaign.campaign_end"/>
						</div>
					</div>
				</fieldset>
		</tab-content>
		<tab-content title="Create Ad" :before-change="validateAdTab">
				<fieldset v-model="modelAds">
					<div class="form-group">
						<label for="ad_name" class="form-label"><?php esc_html_e( 'Ad Name', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_name" class="form-control" type="text" name="ad_name" v-model="modelAds.ad_name"/>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_name.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group">
						<label for="ad_type" class="form-label"><?php esc_html_e( 'Ad Type', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="ad_type" class="form-control" name="ad_type" v-model="modelAds.ad_type">
								<option v-for="ad_type in modelAds.ad_types" :value="ad_type.id">{{ad_type.name}}</option>
							</select>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type==='image'">
						<label for="ad_image_file" class="form-label"><?php esc_html_e( 'Image', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_image_file" class="button button-primary" type="button" name="ad_image_file" v-model="modelAds.ad_image_file" v-on:click="uploadAdImage"><span id="ad_image_filename" class="ad_image_filename"></span>
							<input id="ad_image" type="hidden" name="ad_image" v-model="modelAds.ad_image"/>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_image.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type==='external_image_link'">
						<label for="ad_image_link_url" class="form-label"><?php esc_html_e( 'External Image Link URL', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_image_link_url" class="form-control" type="url" name="ad_image_link_url" v-model="modelAds.ad_image_link_url"/>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_image_link_url.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_image_link_url.url"><?php esc_html_e( 'Invalid url!', 'wpadcenter' ); ?></span>
							<span class="form-help"><?php esc_html_e( 'Link to the external image including http(s).', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type==='ad_code'">
						<label for="ad_code" class="form-label"><?php esc_html_e( 'Ad Code', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<textarea id="ad_code" class="form-control" name="ad_code" v-model="modelAds.ad_code" rows="5"></textarea>
							<span class="form-help"><?php esc_html_e( 'Any ad network, Amazon, customized AdSense codes, and code like JavaScript, or HTML.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type!=='ad_code' && modelAds.ad_type!=='adsense_code'">
						<label for="ad_link_url" class="form-label"><?php esc_html_e( 'Link URL', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_link_url" class="form-control" type="url" name="ad_link_url" v-model="modelAds.ad_link_url"/>
							<span class="form-help"><?php esc_html_e( 'Link to the target site including http(s).', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type!=='ad_code' && modelAds.ad_type!=='adsense_code'">
						<label for="ad_link_target" class="form-label"><?php esc_html_e( 'Open Link in New Tab', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_link_target" class="form-control" type="checkbox" name="ad_link_target" v-model="modelAds.ad_link_target" value="true" checked/>
							<span class="form-help"><?php esc_html_e( 'Open links in a new browser tab by default.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type!=='ad_code' && modelAds.ad_type!=='adsense_code'">
						<label for="ad_link_nofollow" class="form-label"><?php esc_html_e( 'Use nofollow on Link', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<input id="ad_link_nofollow" class="form-control" type="checkbox" name="ad_link_nofollow" v-model="modelAds.ad_link_nofollow" value="true"/>
							<span class="form-help"><?php esc_html_e( 'Use the nofollow attribute to links so search engines don\'t index them.', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group">
						<label for="ad_advertiser" class="form-label"><?php esc_html_e( 'Advertiser', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="ad_advertiser" class="form-control" name="ad_advertiser" v-model="modelAds.ad_advertiser" v-on:change="adAdvertiserChange">
								<option v-for="ad_advertiser in modelAds.ad_advertisers" :value="ad_advertiser.id">{{ad_advertiser.name}}</option>
							</select>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_advertiser.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group">
						<label for="ad_campaign" class="form-label"><?php esc_html_e( 'Campaign', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="ad_campaign" class="form-control" name="ad_campaign" v-model="modelAds.ad_campaign" v-on:change="adCampaignChange">
								<option v-for="ad_campaign in modelAds.ad_campaigns" :value="ad_campaign.id">{{ad_campaign.name}}</option>
							</select>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_campaign.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group">
						<label for="ad_adzone" class="form-label"><?php esc_html_e( 'Adzone', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<select id="ad_adzone" class="form-control" name="ad_adzone" v-model="modelAds.ad_adzone" v-on:change="adAdzoneChange">
								<option v-for="ad_adzone in modelAds.ad_adzones" :value="ad_adzone.id">{{ad_adzone.name}}</option>
							</select>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_adzone.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
					<div class="form-group" v-show="modelAds.ad_type==='adsense_code'">
						<label for="adsense-adunits" class="form-label"><?php esc_html_e( 'Ad', 'wpadcenter' ); ?></label>
						<div class="form-content">
							<?php if ( empty( $ads_data['adunits'] ) ) : ?>
								<?php $url = admin_url( 'admin.php?page=wpadcenter-settings#wpadcenter-adsense' ); ?>

								<a href='<?php echo esc_attr( $url ); ?>'> <?php esc_html_e( 'Connect to Adsense', 'wpadcenter' ); ?></a>

							<?php else : ?>
								<?php $nonce = wp_create_nonce( 'wpeka-google-adsense' ); ?>
								<script>
									if ('undefined' == typeof window.AdsenseGAPI) {
										AdsenseGAPI = {};
									}
									AdsenseGAPI.nonce = '<?php echo esc_html( $nonce ); ?>';
								</script>
								<table class="form-table" v-show="modelAds.ad_type!=='ad_code'">
									<thead>
									<th><?php esc_html_e( 'Name', 'wpadcenter' ); ?></th>
									<th><?php esc_html_e( 'Status', 'wpadcenter' ); ?></th>
									</thead>
									<tbody id="adsense-adunits">


									<?php foreach ( $ads_data['adunits'] as $unit ) : ?>

										<tr>
											<td><?php echo esc_html( $unit['name'] ); ?></td>
											<td><?php echo esc_html( $unit['status'] ); ?></td>
											<td>
												<button v-on:click="loadAdCode" class="button button-primary" data-unitid="<?php echo esc_attr( $unit['id'] ); ?>" id="<?php echo esc_attr( $unit['code'] ); ?>">
													<?php esc_html_e( 'Load', 'wpadcenter' ); ?>
												</button>
												<span class="spinner"></span>
											</td>
										</tr>
									<?php endforeach; ?>
									</tbody>
								</table>
							<?php endif; ?>

							<texarea v-model="modelAds.google_adsense_code" id="acf-field_google_adsense_code" name="acf-field_google_adsense_code" style="display: none;"></texarea>
							<span class="has-error" v-if="submitted && !$v.modelAds.ad_adzone.required"><?php esc_html_e( 'Field is required!', 'wpadcenter' ); ?></span>
						</div>
					</div>
				</fieldset>
		</tab-content>
	</form-wizard>
</div>
</div>
