<?php
/**
 * Provide a admin area view for the getting started page.
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://club.wpeka.com
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/admin/views
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
?>
<div style="clear:both;"></div>
<div class="wrap">
	<h2></h2>
	<div class="wpadcenter-getting-started">
		<h1 style="text-align: center;"><img src="<?php echo esc_url_raw( WPADCENTER_PLUGIN_URL ) . 'admin/images/wpadcenter-logo.png'; ?>" alt="WPAdCenter Logo"/></h1>
		<h2><?php esc_attr_e( '1. Setup WPAdCenter', 'wpadcenter' ); ?></h2>
		<div>
			<p><?php esc_attr_e( 'Configure WPAdCenter settings including:', 'wpadcenter' ); ?></p>
			<ul>
				<li><?php esc_attr_e( 'Auto-refresh of ads', 'wpadcenter' ); ?></li>
				<li><?php esc_attr_e( 'Transitions, and more', 'wpadcenter' ); ?></li>
				<?php do_action( 'wpadcenter_getting_started_setup_items' ); ?>
			</ul>
			<a class="button button-primary" href="<?php menu_page_url( 'wpadcenter-settings', true ); ?>" target="_blank"><?php esc_attr_e( 'Configure WPAdCenter', 'wpadcenter' ); ?></a>
		</div>
		<h2><?php esc_attr_e( '2. Create Ad Zones', 'wpadcenter' ); ?></h2>
		<div>
			<p><?php esc_attr_e( 'Ad Zone contains multiple ads. They can be displayed anywhere on your website using a simple WordPress Gutenberg block.', 'wpadcenter' ); ?></p>
			<a class="button button-primary" href="<?php echo esc_url( admin_url() . 'post-new.php?post_type=wpadcenter-adzones' ); ?>" target="_blank"><?php esc_attr_e( 'Create Ad Zone', 'wpadcenter' ); ?></a>
		</div>
		<h2><?php esc_attr_e( '3. Add Advertisers', 'wpadcenter' ); ?></h2>
		<div>
			<p><?php esc_attr_e( 'Advertisers pay you to display banner ads on your website. Before you create banner ads, you’ll need to create an advertiser.', 'wpadcenter' ); ?></p>
			<a class="button button-primary" href="<?php echo esc_url( admin_url() . 'user-new.php' ); ?>" target="_blank"><?php esc_attr_e( 'Add Advertiser', 'wpadcenter' ); ?></a>
		</div>
		<h2><?php esc_attr_e( '4. Create Campaigns', 'wpadcenter' ); ?></h2>
		<div>
			<p><?php esc_attr_e( 'Campaigns determine how long your ads run.', 'wpadcenter' ); ?></p>
			<a class="button button-primary" href="<?php echo esc_url( admin_url() . 'post-new.php?post_type=wpadcenter-campaigns' ); ?>" target="_blank"><?php esc_attr_e( 'Create Campaign', 'wpadcenter' ); ?></a>
		</div>
		<h2><?php esc_attr_e( '5. Create Ads', 'wpadcenter' ); ?></h2>
		<div>
			<p><?php esc_attr_e( 'Ads can be banner images, external image URLs, or javascript code from Google AdSense, Amazon Shopping, Media.net or other any ad network.', 'wpadcenter' ); ?></p>
			<a class="button button-primary" href="<?php echo esc_url( admin_url() . 'post-new.php?post_type=wpadcenter-banners' ); ?>" target="_blank"><?php esc_attr_e( 'Create Ad', 'wpadcenter' ); ?></a>
		</div>
		<?php do_action( 'wpadcenter_getting_started_setup_steps' ); ?>
		<h1><?php esc_attr_e( 'About WPAdCenter', 'wpadcenter' ); ?></h1>
		<div>
			<p><?php esc_attr_e( 'WPAdCenter is a Powerful WordPress Ads Plugin. You can control every aspect of advertising on any WordPress powered website. Place ads or Ad scripts anywhere on your site. Compatible with Gutenberg & Popular Page Builders.', 'wpadcenter' ); ?></p>
		</div>
		<h2><?php esc_attr_e( 'Help & Support', 'wpadcenter' ); ?></h2>
		<div>
			<ul>
				<li><a href="https://docs.wpeka.com/wp-adcenter/?utm_source=wpadcenter&utm_medium=getting-started&utm_campaign=link&utm_content=documentation" target="_blank"><?php esc_attr_e( 'Documentation', 'wpadcenter' ); ?></a></li>
				<?php if ( get_option( 'wpadcenter_pro_installed' ) ) : ?>
					<li><a href="https://club.wpeka.com/my-account/orders/?utm_source=wpadcenter&utm_medium=getting-started&utm_campaign=link&utm_content=support" target="_blank"><?php esc_attr_e( 'Support', 'wpadcenter' ); ?></a></li>
				<?php else : ?>
					<li><a href="https://wordpress.org/support/plugin/wpadcenter/?utm_source=wpadcenter&utm_medium=getting-started&utm_campaign=link&utm_content=forums" target="_blank"><?php esc_attr_e( 'Forums', 'wpadcenter' ); ?></a></li>
					<li><a href="https://club.wpeka.com/product/wpadcenter/?utm_source=wpadcenter&utm_medium=getting-started&utm_campaign=link&utm_content=upgrade-to-wpadcenter-pro" target="_blank"><?php esc_attr_e( 'Upgrade to WPAdCenter Pro', 'wpadcenter' ); ?></a></li>
				<?php endif; ?>
			</ul>
		</div>
	</div>
</div>
