<?php
/**
 * Fired during plugin activation
 *
 * @link       https://club.wpeka.com/
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Wpadcenter
 * @subpackage Wpadcenter/includes
 * @author     WPEka Club <support@wpeka.com>
 */
class Wpadcenter_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		if ( ! wp_next_scheduled( 'wpadcenter_daily_cron' ) ) {
			wp_schedule_event( strtotime( 'tomorrow' ), 'daily', 'wpadcenter_daily_cron' );
		}
		// Update settings from Version 1.0.1.
		$prev_options = get_option( 'WPAdCenter-1.0' );
		if ( isset( $prev_options ) && is_array( $prev_options ) ) {
			$prev_options['enable_scripts']     = false;
			$prev_options['header_scripts']     = '';
			$prev_options['body_scripts']       = '';
			$prev_options['footer_scripts']     = '';
			$prev_options['enable_advertisers'] = false;
			unset( $prev_options['notification_email'] );
			unset( $prev_options['notification_name'] );
			unset( $prev_options['paypal'] );
			unset( $prev_options['paypal_email'] );
			unset( $prev_options['paypal_currency'] );
			unset( $prev_options['paypal_sandbox'] );
			unset( $prev_options['stripe'] );
			unset( $prev_options['stripe_secret_key'] );
			unset( $prev_options['stripe_publisher_key'] );
			unset( $prev_options['stripe_currency'] );
			update_option( WPADCENTER_SETTINGS_FIELD, $prev_options );
			delete_option( 'WPAdCenter-1.0' );
		}
		// Update setting from Version 1.0.3.
		$prev_options = get_option( 'WPAdCenter-2.0' );
		if ( isset( $prev_options ) && is_array( $prev_options ) ) {
			$prev_options['trim_stats'] = '0';
			update_option( WPADCENTER_SETTINGS_FIELD, $prev_options );
			delete_option( 'WPAdCenter-2.0' );
		}
		// Update setting from Version 1.0.4.
		$prev_options = get_option( 'WPAdCenter-3.0' );
		if ( isset( $prev_options ) && is_array( $prev_options ) ) {
			$prev_options['enable_ads_txt']  = false;
			$prev_options['ads_txt_content'] = '';
			update_option( WPADCENTER_SETTINGS_FIELD, $prev_options );
			delete_option( 'WPAdCenter-3.0' );
		}
		add_option( 'wpadcenter_active', true );
	}

}
