<?php
/**
 * AdSense Api integration.
 *
 * @link       https://club.wpeka.com
 * @since      1.0.1
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/includes
 */

namespace Wpeka\Adcenter;

/**
 * Class Wpadcenter_Meta_Boxes
 *
 * @package Wpeka\Adcenter
 */
class Wpadcenter_Meta_Boxes {

	/**
	 * Adds meta boxes to Ads, adzones,campaigns.
	 */
	public static function add_acf_fields() {
		$the_options = \Wpadcenter::wpadcenter_get_settings();

		do_action( 'wpadcenter_before_adzones_acf_fields' );

		if ( function_exists( 'acf_add_local_field_group' ) ) {
			// Ad Zones – General.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_adzones_content',
					'title'                 => __( 'Content', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_adzones_content_fields',
						array(
							array(
								'key'               => 'field_adzones_description',
								'label'             => __( 'Description', 'wpadcenter' ),
								'name'              => 'adzones_description',
								'type'              => 'textarea',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => '',
								'placeholder'       => '',
								'maxlength'         => '',
								'rows'              => '',
								'new_lines'         => '',
							),
							array(
								'key'               => 'field_text_above_ad_zone',
								'label'             => __( 'Text above Ad Zone', 'wpadcenter' ),
								'name'              => 'text_above_ad_zone',
								'type'              => 'textarea',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => '',
								'placeholder'       => '',
								'maxlength'         => '',
								'rows'              => '',
								'new_lines'         => '',
							),
							array(
								'key'               => 'field_text_below_ad_zone',
								'label'             => __( 'Text below Ad Zone', 'wpadcenter' ),
								'name'              => 'text_below_ad_zone',
								'type'              => 'textarea',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => '',
								'placeholder'       => '',
								'maxlength'         => '',
								'rows'              => '',
								'new_lines'         => '',
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-adzones',
							),
						),
					),
					'menu_order'            => 1,
					'position'              => 'acf_after_title',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);

			// Ad Zones – Settings.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_adzones_general',
					'title'                 => __( 'General Settings', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_adzones_general_fields',
						array(
							array(
								'key'               => 'field_template',
								'label'             => __( 'Template', 'wpadcenter' ),
								'name'              => 'template',
								'type'              => 'select',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'choices'           => apply_filters(
									'wpadcenter_adzones_template_field_choices',
									array(
										'468x60'  => __( 'IAB Full Banner (468 x 60)', 'wpadcenter' ),
										'120x600' => __( 'IAB Skyscraper (120 x 600)', 'wpadcenter' ),
										'160x600' => __( 'IAB Wide Skyscraper (160 x 600)', 'wpadcenter' ),
										'728x90'  => __( 'IAB Leaderboard (728 x 90)', 'wpadcenter' ),
										'180x150' => __( 'IAB Rectangle (180 x 150)', 'wpadcenter' ),
										'300x250' => __( 'IAB Medium Rectangle (300 x 250)', 'wpadcenter' ),
										'120x90'  => __( 'IAB Button 1 (120 x 90)', 'wpadcenter' ),
										'120x60'  => __( 'IAB Button 2 (120 x 60)', 'wpadcenter' ),
										'125x125' => __( 'IAB Square Button (125 x 125)', 'wpadcenter' ),
										'0'       => __( 'Custom', 'wpadcenter' ),
									)
								),
								'default_value'     => array(
									0 => '468x60',
								),
								'allow_null'        => 0,
								'multiple'          => 0,
								'ui'                => 1,
								'ajax'              => 0,
								'return_format'     => 'value',
								'placeholder'       => '',
							),
							array(
								'key'               => 'field_custom_width',
								'label'             => __( 'Width (in px)', 'wpadcenter' ),
								'name'              => 'custom_width',
								'type'              => 'number',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => array(
									array(
										array(
											'field'    => 'field_template',
											'operator' => '==',
											'value'    => '0',
										),
									),
								),
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => 600,
								'placeholder'       => '',
								'prepend'           => '',
								'append'            => '',
								'min'               => '',
								'max'               => '',
								'step'              => 1,
							),
							array(
								'key'               => 'field_custom_height',
								'label'             => __( 'Height (in px)', 'wpadcenter' ),
								'name'              => 'custom_height',
								'type'              => 'number',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => array(
									array(
										array(
											'field'    => 'field_template',
											'operator' => '==',
											'value'    => '0',
										),
									),
								),
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => 400,
								'placeholder'       => '',
								'prepend'           => '',
								'append'            => '',
								'min'               => '',
								'max'               => '',
								'step'              => 1,
							),
							array(
								'key'               => 'field_auto_refresh_ads',
								'label'             => __( 'Auto Refresh Ads', 'wpadcenter' ),
								'name'              => 'auto_refresh_ads',
								'type'              => 'true_false',
								'instructions'      => __( 'Auto refresh all ads in this adzone.', 'wpadcenter' ),
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'message'           => '',
								'default_value'     => 0,
								'ui'                => 0,
								'ui_on_text'        => '',
								'ui_off_text'       => '',
							),
							array(
								'key'               => 'field_transition_effect',
								'label'             => __( 'Transition Effect', 'wpadcenter' ),
								'name'              => 'transition_effect',
								'type'              => 'select',
								'instructions'      => __(
									'Transition effect for ads, if Auto Refresh is enabled.',
									'wpadcenter'
								),
								'required'          => 0,
								'conditional_logic' => array(
									array(
										array(
											'field'    => 'field_auto_refresh_ads',
											'operator' => '==',
											'value'    => '1',
										),
									),
								),
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'choices'           => apply_filters(
									'wpadcenter_adzones_transition_effect_field_choices',
									array(
										'none'       => __( 'None', 'wpadcenter' ),
										'fade'       => __( 'Fade', 'wpadcenter' ),
										'fadeout'    => __( 'Fade Out', 'wpadcenter' ),
										'scrollHorz' => __( 'Scroll Right to Left', 'wpadcenter' ),
										'scrollHorzReverse' => __( 'Scroll Left to Right', 'wpadcenter' ),
										'scrollVert' => __( 'Scroll Top to Bottom', 'wpadcenter' ),
										'scrollVertReverse' => __( 'Scroll Bottom to Top', 'wpadcenter' ),
									)
								),
								'default_value'     => array(
									0 => 'none',
								),
								'allow_null'        => 0,
								'multiple'          => 0,
								'ui'                => 1,
								'ajax'              => 0,
								'return_format'     => 'value',
								'placeholder'       => '',
							),
							array(
								'key'               => 'field_transition_speed',
								'label'             => __( 'Transition Speed', 'wpadcenter' ),
								'name'              => 'transition_speed',
								'type'              => 'number',
								'instructions'      => __(
									'Speed in milliseconds for ad transitions, if Auto Refresh is enabled.',
									'wpadcenter'
								),
								'required'          => 0,
								'conditional_logic' => array(
									array(
										array(
											'field'    => 'field_auto_refresh_ads',
											'operator' => '==',
											'value'    => '1',
										),
									),
								),
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => 500,
								'placeholder'       => '',
								'prepend'           => '',
								'append'            => '',
								'min'               => 500,
								'max'               => 60000,
								'step'              => 100,
							),
							array(
								'key'               => 'field_transition_delay',
								'label'             => __( 'Transition Delay', 'wpadcenter' ),
								'name'              => 'transition_delay',
								'type'              => 'number',
								'instructions'      => __(
									'Delay in milliseconds between ad transitions, if Auto Refresh is enabled.',
									'wpadcenter'
								),
								'required'          => 0,
								'conditional_logic' => array(
									array(
										array(
											'field'    => 'field_auto_refresh_ads',
											'operator' => '==',
											'value'    => '1',
										),
									),
								),
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => 1000,
								'placeholder'       => '',
								'prepend'           => '',
								'append'            => '',
								'min'               => 1000,
								'max'               => 60000,
								'step'              => 100,
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-adzones',
							),
						),
					),
					'menu_order'            => 1,
					'position'              => 'side',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);

			// Ad Zones – Extra Settings.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_adzones_extra',
					'title'                 => __( 'Extra Settings', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_adzones_extra_fields',
						array(
							array(
								'key'               => 'field_signup_link',
								'label'             => __( 'Signup Page Link', 'wpadcenter' ),
								'name'              => 'signup_link',
								'type'              => 'url',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => '',
								'placeholder'       => '',
							),
							array(
								'key'               => 'field_default_banner',
								'label'             => __( 'Default Banner', 'wpadcenter' ),
								'name'              => 'default_banner',
								'type'              => 'image',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'return_format'     => 'id',
								'preview_size'      => 'thumbnail',
								'library'           => 'all',
								'min_width'         => '',
								'min_height'        => '',
								'min_size'          => '',
								'max_width'         => '',
								'max_height'        => '',
								'max_size'          => '',
								'mime_types'        => '.gif, .jpg, .png, .swf, .bmp',
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-adzones',
							),
						),
					),
					'menu_order'            => 5,
					'position'              => 'side',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);

		}

		do_action( 'wpadcenter_after_adzones_acf_fields' );

		do_action( 'wpadcenter_before_campaigns_acf_fields' );

		if ( function_exists( 'acf_add_local_field_group' ) ) {
			// Campaigns - General.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_campaigns_general',
					'title'                 => __( 'General', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_campaigns_general_fields',
						array(
							array(
								'key'               => 'field_campaigns_description',
								'label'             => __( 'Description', 'wpadcenter' ),
								'name'              => 'campaigns_description',
								'type'              => 'textarea',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'default_value'     => '',
								'placeholder'       => '',
								'maxlength'         => '',
								'rows'              => '',
								'new_lines'         => '',
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-campaigns',
							),
						),
					),
					'menu_order'            => 1,
					'position'              => 'acf_after_title',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);
			// Campaigns - Settings.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_campaigns_settings',
					'title'                 => __( 'Settings', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_campaigns_settings_fields',
						array(
							array(
								'key'               => 'field_campaigns_advertiser',
								'label'             => __( 'Advertiser', 'wpadcenter' ),
								'name'              => 'campaigns_advertiser',
								'type'              => 'user',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'role'              => array(
									0 => 'advertiser',
								),
								'taxonomy'          => '',
								'allow_null'        => 0,
								'multiple'          => 0,
								'return_format'     => 'id',
								'ui'                => 1,
							),
							array(
								'key'               => 'field_start_date',
								'label'             => __( 'Start Date', 'wpadcenter' ),
								'name'              => 'start_date',
								'type'              => 'date_picker',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'display_format'    => 'd/m/Y',
								'return_format'     => 'd/m/Y',
								'first_day'         => 1,
							),
							array(
								'key'               => 'field_end_date',
								'label'             => __( 'End Date', 'wpadcenter' ),
								'name'              => 'end_date',
								'type'              => 'date_picker',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'display_format'    => 'd/m/Y',
								'return_format'     => 'd/m/Y',
								'first_day'         => 1,
							),
							array(
								'key'               => 'field_campaigns_status',
								'label'             => __( 'Status', 'wpadcenter' ),
								'name'              => 'campaigns_status',
								'type'              => 'select',
								'instructions'      => '',
								'required'          => 0,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'choices'           => apply_filters(
									'wpadcenter_campaigns_status_field_choices',
									array(
										'paused'    => __( 'Paused', 'wpadcenter' ),
										'running'   => __( 'Running', 'wpadcenter' ),
										'scheduled' => __( 'Scheduled', 'wpadcenter' ),
										'finished'  => __( 'Finished', 'wpadcenter' ),
									)
								),
								'allow_null'        => 0,
								'mulitple'          => 0,
								'ui'                => 0,
								'default_value'     => array(
									0 => 'running',
								),
								'return_format'     => 'value',
								'ajax'              => 0,
								'placeholder'       => 0,
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-campaigns',
							),
						),
					),
					'menu_order'            => 1,
					'position'              => 'side',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);
		}

		do_action( 'wpadcenter_after_campaigns_acf_fields' );

		do_action( 'wpadcenter_before_banners_acf_fields' );

		if ( function_exists( 'acf_add_local_field_group' ) ) {
			// Ads - General.
			acf_add_local_field_group(
				self::get_ads_general_fields()
			);

			// Ad - Settings.
			acf_add_local_field_group(
				array(
					'key'                   => 'group_banners_settings',
					'title'                 => __( 'Ad - Settings', 'wpadcenter' ),
					'fields'                => apply_filters(
						'wpadcenter_banners_settings_fields',
						array(
							array(
								'key'               => 'field_banners_advertiser',
								'label'             => __( 'Advertiser', 'wpadcenter' ),
								'name'              => 'banners_advertiser',
								'type'              => 'user',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'role'              => array(
									0 => 'advertiser',
								),
								'taxonomy'          => '',
								'allow_null'        => 0,
								'multiple'          => 0,
								'return_format'     => 'id',
								'ui'                => 1,
							),
							array(
								'key'               => 'field_banners_campaign',
								'label'             => __( 'Campaign', 'wpadcenter' ),
								'name'              => 'banners_campaign',
								'type'              => 'post_object',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'post_type'         => array(
									0 => 'wpadcenter-campaigns',
								),
								'taxonomy'          => '',
								'allow_null'        => 0,
								'multiple'          => 0,
								'return_format'     => 'id',
								'ui'                => 1,
							),
							array(
								'key'               => 'field_banners_ad_zone',
								'label'             => __( 'Ad Zone', 'wpadcenter' ),
								'name'              => 'banners_ad_zone',
								'type'              => 'post_object',
								'instructions'      => '',
								'required'          => 1,
								'conditional_logic' => 0,
								'wrapper'           => array(
									'width' => '',
									'class' => '',
									'id'    => '',
								),
								'post_type'         => array(
									0 => 'wpadcenter-adzones',
								),
								'taxonomy'          => '',
								'allow_null'        => 0,
								'multiple'          => 0,
								'return_format'     => 'id',
								'ui'                => 1,
							),
						)
					),
					'location'              => array(
						array(
							array(
								'param'    => 'post_type',
								'operator' => '==',
								'value'    => 'wpadcenter-banners',
							),
						),
					),
					'menu_order'            => 1,
					'position'              => 'side',
					'style'                 => 'default',
					'label_placement'       => 'left',
					'instruction_placement' => 'field',
					'hide_on_screen'        => '',
					'active'                => true,
					'description'           => '',
				)
			);
		}

		do_action( 'wpadcenter_after_banners_acf_fields' );

		do_action( 'wpadcenter_before_scripts_acf_fields' );

		if ( function_exists( 'acf_add_local_field_group' ) ) {
			if ( $the_options['enable_scripts'] ) {
				// WPAdCenter Scripts.
				acf_add_local_field_group(
					array(
						'key'                   => 'group_wpadcenter_scripts',
						'title'                 => __( 'WPAdCenter Scripts', 'wpadcenter' ),
						'fields'                => apply_filters(
							'wpadcenter_scripts_fields',
							array(
								array(
									'key'               => 'field_disable_global_scripts',
									'label'             => __( 'Disable Global Scripts', 'wpadcenter' ),
									'name'              => 'disable_global_scripts',
									'type'              => 'true_false',
									'instructions'      => '',
									'required'          => 0,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'message'           => '',
									'default_value'     => 0,
									'ui'                => 0,
									'ui_on_text'        => '',
									'ui_off_text'       => '',
								),
								array(
									'key'               => 'field_header_scripts',
									'label'             => __( 'Header Scripts', 'wpadcenter' ),
									'name'              => 'header_scripts',
									'type'              => 'textarea',
									'instructions'      => __(
										'These scripts will be printed in the head section.',
										'wpadcenter'
									),
									'required'          => 0,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'default_value'     => '',
									'placeholder'       => '',
									'maxlength'         => '',
									'rows'              => '',
									'new_lines'         => '',
								),
								array(
									'key'               => 'field_body_scripts',
									'label'             => __( 'Body Scripts', 'wpadcenter' ),
									'name'              => 'body_scripts',
									'type'              => 'textarea',
									'instructions'      => __(
										'These scripts will be printed just below the opening body tag.',
										'wpadcenter'
									),
									'required'          => 0,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'default_value'     => '',
									'placeholder'       => '',
									'maxlength'         => '',
									'rows'              => '',
									'new_lines'         => '',
								),
								array(
									'key'               => 'field_footer_scripts',
									'label'             => __( 'Footer Scripts', 'wpadcenter' ),
									'name'              => 'footer_scripts',
									'type'              => 'textarea',
									'instructions'      => __(
										'These scripts will be printed above the closing body tag.',
										'wpadcenter'
									),
									'required'          => 0,
									'conditional_logic' => 0,
									'wrapper'           => array(
										'width' => '',
										'class' => '',
										'id'    => '',
									),
									'default_value'     => '',
									'placeholder'       => '',
									'maxlength'         => '',
									'rows'              => '',
									'new_lines'         => '',
								),
							)
						),
						'location'              => array(
							array(
								array(
									'param'    => 'post_type',
									'operator' => '==',
									'value'    => 'post',
								),
							),
							array(
								array(
									'param'    => 'post_type',
									'operator' => '==',
									'value'    => 'page',
								),
							),
						),
						'menu_order'            => 1,
						'position'              => 'normal',
						'style'                 => 'default',
						'label_placement'       => 'left',
						'instruction_placement' => 'field',
						'hide_on_screen'        => '',
						'active'                => true,
						'description'           => '',
					)
				);
			}
		}

		do_action( 'wpadcenter_after_scripts_acf_fields' );

	}

	/**
	 * Get metaboxes for ads custom type post
	 *
	 * @return array
	 */
	public static function get_ads_general_fields() {

		$fields = array(
			array(
				'key'               => 'field_banner_type',
				'label'             => __( 'Ad Type', 'wpadcenter' ),
				'name'              => 'banner_type',
				'type'              => 'select',
				'instructions'      => '',
				'required'          => 0,
				'conditional_logic' => 0,
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'choices'           => apply_filters(
					'wpadcenter_banners_type_field_choices',
					array(
						'image'               => __( 'Banner Image', 'wpadcenter' ),
						'external_image_link' => __( 'External Image Link', 'wpadcenter' ),
						'ad_code'             => __( 'Ad Code', 'wpadcenter' ),
						'adsense_code'        => __( 'Import From Adsense', 'wpadcenter' ),
					)
				),
				'default_value'     => array(
					0 => 'image',
				),
				'allow_null'        => 0,
				'multiple'          => 0,
				'ui'                => 0,
				'return_format'     => 'value',
				'ajax'              => 0,
				'placeholder'       => '',
			),
			array(
				'key'               => 'field_image',
				'label'             => __( 'Image', 'wpadcenter' ),
				'name'              => 'image',
				'type'              => 'image',
				'instructions'      => '',
				'required'          => 1,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '==',
							'value'    => 'image',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'return_format'     => 'id',
				'preview_size'      => 'thumbnail',
				'library'           => 'all',
				'min_width'         => '',
				'min_height'        => '',
				'min_size'          => '',
				'max_width'         => '',
				'max_height'        => '',
				'max_size'          => '',
				'mime_types'        => '',
			),
			array(
				'key'               => 'field_image_link',
				'label'             => __( 'External Image Link', 'wpadcenter' ),
				'name'              => 'image_link',
				'type'              => 'url',
				'instructions'      => __( 'Link to the external image including http(s).', 'wpadcenter' ),
				'required'          => 1,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '==',
							'value'    => 'external_image_link',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'default_value'     => '',
				'placeholder'       => '',
			),
			array(
				'key'               => 'field_ad_code',
				'label'             => __( 'Ad Code', 'wpadcenter' ),
				'name'              => 'ad_code',
				'type'              => 'textarea',
				'instructions'      => __(
					'Any ad network, Amazon, customized AdSense codes, and code like JavaScript, or HTML.',
					'wpadcenter'
				),
				'required'          => 1,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '==',
							'value'    => 'ad_code',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'default_value'     => '',
				'placeholder'       => '',
				'maxlength'         => '',
				'rows'              => '',
				'new_lines'         => '',
			),
			array(
				'key'               => 'field_google_adsense_code',
				'label'             => __( 'Ad google adsense', 'wpadcenter' ),
				'name'              => 'google_adsense_code',
				'type'              => 'textarea',
				'instructions'      => __( 'Google adsense', 'wpadcenter' ),
				'required'          => 1,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '==',
							'value'    => 'adsense_code',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'default_value'     => '',
				'placeholder'       => '',
				'maxlength'         => '',
				'rows'              => '',
				'new_lines'         => '',
			),
			array(
				'key'               => 'field_link_url',
				'label'             => __( 'Link URL', 'wpadcenter' ),
				'name'              => 'link_url',
				'type'              => 'url',
				'instructions'      => __( 'Link to the target site including http(s).', 'wpadcenter' ),
				'required'          => 0,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'ad_code',
						),
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'adsense_code',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'default_value'     => '',
				'placeholder'       => '',
			),
			array(
				'key'               => 'field_link_target',
				'label'             => __( 'Open Link in New Tab', 'wpadcenter' ),
				'name'              => 'link_target',
				'type'              => 'true_false',
				'instructions'      => __( 'Open links in a new browser tab by default.', 'wpadcenter' ),
				'required'          => 0,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'ad_code',
						),
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'adsense_code',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'message'           => '',
				'default_value'     => true,
				'ui'                => 0,
				'ui_on_text'        => '',
				'ui_off_text'       => '',
			),
			array(
				'key'               => 'field_link_nofollow',
				'label'             => __( 'Use nofollow on Link', 'wpadcenter' ),
				'name'              => 'link_nofollow',
				'type'              => 'true_false',
				'instructions'      => __(
					'Use the nofollow attribute to links so search engines don\'t index them.',
					'wpadcenter'
				),
				'required'          => 0,
				'conditional_logic' => array(
					array(
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'ad_code',
						),
						array(
							'field'    => 'field_banner_type',
							'operator' => '!=',
							'value'    => 'adsense_code',
						),
					),
				),
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'message'           => '',
				'default_value'     => true,
				'ui'                => 0,
				'ui_on_text'        => '',
				'ui_off_text'       => '',
			),
		);

		return array(
			'key'                   => 'group_banners_general',
			'title'                 => __( 'General', 'wpadcenter' ),
			'fields'                => apply_filters( 'wpadcenter_banners_general_fields', $fields ),
			'location'              => array(
				array(
					array(
						'param'    => 'post_type',
						'operator' => '==',
						'value'    => 'wpadcenter-banners',
					),
				),
			),
			'menu_order'            => 1,
			'position'              => 'acf_after_title',
			'style'                 => 'default',
			'label_placement'       => 'left',
			'instruction_placement' => 'field',
			'hide_on_screen'        => '',
			'active'                => true,
			'description'           => '',
		);
	}
}
