<?php
/**
 * The widget-specific functionality of the plugin.
 *
 * @link       https://club.wpeka.com/
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/includes
 */

/**
 * The widget-specific functionality of the plugin.
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/includes
 * @author     WPEka Club <support@wpeka.com>
 */
class Wpadcenter_Widget extends \WP_Widget {

	/**
	 * Wpadcenter_Widget constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$id_base        = 'Wpadcenter_Widget';
		$name           = 'WPAdCenter';
		$widget_options = array( 'description' => __( 'Display ads in a Widget', 'wpadcenter' ) );
		parent::__construct( $id_base, $name, $widget_options );
		if ( is_active_widget( false, false, 'wpadcenter_widget' ) ) {
			add_action( 'wp_head', array( $this, 'wpadcenter_load_scripts' ) );
		}
	}

	/**
	 * Load widget scripts.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_load_scripts() {
		wp_enqueue_script( 'wpadcenter-frontend' );
		wp_enqueue_script( 'wpadcenter-cycle2' );
		wp_enqueue_style( 'wpadcenter-block' );
		wp_localize_script(
			'wpadcenter-frontend',
			'ajax_url',
			array(
				'url'      => admin_url( 'admin-ajax.php' ),
				'security' => wp_create_nonce( 'wpadcenter_set_clicks' ),
			)
		);
	}

	/**
	 * Display functionality for widget.
	 *
	 * @since 1.0.0
	 * @param array $args Arguments.
	 * @param array $instance Widget instance.
	 */
	public function widget( $args, $instance ) {
		$before_widget = isset( $args['before_widget'] ) ? $args['before_widget'] : '';
		$after_widget  = isset( $args['after_widget'] ) ? $args['after_widget'] : '';
		if ( isset( $instance['adzone_id'] ) && '0' !== $instance['adzone_id'] ) {
			$container_styles = '';
			$message          = '';
			$adzone_id        = $instance['adzone_id'];
			$the_options      = Wpadcenter::wpadcenter_get_settings();
			$geo_location     = $the_options['geo_location'];
			$auto_refresh     = $the_options['auto_refresh'];
			if ( $auto_refresh ) {
				$transition = $the_options['transition_effect'];
				$speed      = $the_options['transition_speed'];
				$delay      = $the_options['transition_delay'];
			}
			$numberofposts     = -1;
			$container_styles .= 'width:100%;height:auto;margin:0;padding:0;';
			$adzone_display    = true;
			if ( 'adzone' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
				$adzone_display = apply_filters( 'wpadcenter_geolocation_adzone', $adzone_id );
			}
			if ( $adzone_display ) {
				$auto_refresh_override = get_field( 'auto_refresh_ads', $adzone_id );
				if ( $auto_refresh_override ) {
					$auto_refresh = $auto_refresh_override;
					$transition   = get_field( 'transition_effect', $adzone_id );
					$speed        = get_field( 'transition_speed', $adzone_id );
					$delay        = get_field( 'transition_delay', $adzone_id );
				}
				$adzone_default_banner = get_field( 'default_banner', $adzone_id );
				$adzone_signup_link    = get_field( 'signup_link', $adzone_id );
				$adzone_template       = get_field( 'template', $adzone_id );
				if ( $adzone_template && '0' !== $adzone_template ) {
					$adzone_size = explode( 'x', $adzone_template );
				} else {
					$adzone_size[0] = get_field( 'custom_width', $adzone_id );
					$adzone_size[1] = get_field( 'custom_height', $adzone_id );
				}
				$adzone_text_above = get_field( 'text_above_ad_zone', $adzone_id );
				$adzone_text_below = get_field( 'text_below_ad_zone', $adzone_id );
				$width             = $adzone_size['0'];
				$height            = $adzone_size['1'];
				$adzone_rows       = get_field( 'horizontal', $adzone_id );
				$adzone_columns    = get_field( 'vertical', $adzone_id );
				$adzone_classes    = 'adzone_1_1';
				if ( $adzone_rows && $adzone_columns && ! $auto_refresh ) {
					$adzone_classes = 'adzone_' . $adzone_rows . '_' . $adzone_columns;
					$numberofposts  = $adzone_columns * $adzone_rows;
				}
				$args      = array(
					'post_type'   => 'wpadcenter-campaigns',
					'post_status' => 'adc-running',
					'numberposts' => -1,
					'orderby'     => 'rand',
					'order'       => 'ASC',
				);
				$campaigns = get_posts( $args );
				if ( $campaigns ) {
					$campaign_ids = array();
					if ( 'campaign' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
						$campaign_ids = apply_filters( 'wpadcenter_geolocation_campaigns', $campaigns );
					} else {
						foreach ( $campaigns as $campaign ) {
							$campaign_ids[] = $campaign->ID;
						}
					}
					if ( empty( $campaign_ids ) ) {
						$campaign_ids = '';
					}
					$args    = array(
						'post_type'   => 'wpadcenter-banners',
						'post_status' => 'publish',
						'numberposts' => $numberofposts,
						'orderby'     => 'rand',
						'order'       => 'ASC',
						'meta_query'  => array( // phpcs:ignore slow query
							'relation' => 'AND',
							array(
								'key'     => 'banners_campaign',
								'value'   => $campaign_ids,
								'compare' => 'IN',
							),
							array(
								'key'     => 'banners_ad_zone',
								'value'   => $adzone_id,
								'compare' => '=',
							),
						),
					);
					$banners = get_posts( $args );
					if ( $banners ) {
						$message  = apply_filters( 'wpadcenter_block_render_before', $message );
						$message .= '<div class="wpadcenter-text-above">' . $adzone_text_above . '</div>';
						if ( $auto_refresh ) {
							$container_styles .= 'max-width:' . $width . 'px;';
							$message          .= '<div class="wpadcenter-slider cycle-slideshow" data-slides="div.wpadcenter-slide" data-cycle-fx="' . $transition . '" data-cycle-speed="' . $speed . '" data-cycle-delay="' . $delay . '" data-cycle-auto-height="container">';
						} else {
							$message .= '<div class="wpadcenter-slider">';
						}
						foreach ( $banners as $banner ) {
							$banner_id          = $banner->ID;
							$banner_link_url    = get_field( 'link_url', $banner_id );
							$banner_link_target = get_field( 'link_target', $banner_id );
							if ( $banner_link_target && '_blank' !== $banner_link_target && true !== $banner_link_target ) {
								$banner_link_target = '_self';
							} elseif ( $banner_link_target ) {
								$banner_link_target = '_blank';
							} else {
								$banner_link_target = '_self';
							}
							$banner_link_nofollow = get_field( 'link_nofollow', $banner_id );
							$banner_advertiser    = get_field( 'banners_advertiser', $banner_id );
							$banner_campaign      = get_field( 'banners_campaign', $banner_id );
							$banner_ad_zone       = get_field( 'banners_ad_zone', $banner_id );
							$banner_type          = get_field( 'banner_type', $banner_id );
							$message             .= '<div class="wpadcenter-slide ' . $adzone_classes . '">';
							if ( get_option( 'wpadcenter_pro_active' ) ) {
								$message .= '<input type="hidden" name="banner_id" value="' . $banner_id . '">';
								$message .= '<input type="hidden" name="banner_advertiser" value="' . $banner_advertiser . '">';
								$message .= '<input type="hidden" name="banner_campaign" value="' . $banner_campaign . '">';
								$message .= '<input type="hidden" name="banner_ad_zone" value="' . $banner_ad_zone . '">';
								if ( get_option( 'wpadcenter_pro_active' ) ) {
									Wpadcenter::wpadcenter_set_impressions( $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone );
								}
							}
							$message .= '<a class="link" href="' . $banner_link_url . '" target="' . $banner_link_target . '"';
							if ( $banner_link_nofollow ) {
								$message .= ' rel="nofollow"';
							}
							$message .= '>';
							switch ( $banner_type ) {
								case 'image':
									$banner_img = get_field( 'image', $banner_id );
									$banner_img = wp_get_attachment_image( $banner_img, $width, $height );
									$message   .= $banner_img;
									break;
								case 'external_image_link':
									$banner_img_link = get_field( 'image_link', $banner_id );
									$message        .= '<img width="' . $width . '" height="' . $height . '" src="' . esc_url( $banner_img_link ) . '"/>';
									break;
								case 'ad_code':
									$banner_ad_code = get_field( 'ad_code', $banner_id );
									$message       .= '<span class="wpadcenter-ad-code">' . $banner_ad_code . '</span>';
									break;
								case 'adsense_code':
									$banner_ad_code = get_field( 'field_google_adsense_code', $banner_id );
									$message       .= '<div style="min-height:200px;min-width: 200px" class="wpadcenter-ad-code">' . $banner_ad_code . '</div>';
									break;
							}
							$message .= '</a>';
							$message .= '</div>';
						}
						$message .= '</div>';
						$message .= '<div class="wpadcenter-text-below">' . $adzone_text_below . '</div>';
					} else {
						if ( $adzone_default_banner ) {
							$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
							$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
							$message           .= $default_banner_img;
							$message           .= '</a>';
						}
					}
				} else {
					if ( $adzone_default_banner ) {
						$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
						$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
						$message           .= $default_banner_img;
						$message           .= '</a>';
					}
				}
			}
			echo $before_widget; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			?>
			<div class="wpadcenter-block-container" style="<?php echo $container_styles; ?>"><?php echo $message; ?></div> <?php // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<?php
			echo $after_widget; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Widget update functionality.
	 *
	 * @since 1.0.0
	 * @param array $new_instance Widget new instance.
	 * @param array $old_instance Widget old instance.
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		return $new_instance;
	}

	/**
	 * Widget form.
	 *
	 * @since 1.0.0
	 * @param array $instance Widget instance.
	 * @return string|void
	 */
	public function form( $instance ) {
		if ( isset( $instance ) ) {
			$adzone_id  = isset( $instance['adzone_id'] ) ? esc_attr( $instance['adzone_id'] ) : 0;
			$ad_zones   = array();
			$ad_zones[] = __( 'Select Ad Zone', 'wpadcenter' );
			$args       = array(
				'post_type'   => 'wpadcenter-adzones',
				'post_status' => 'publish',
				'numberposts' => -1,
			);
			$adzones    = get_posts( $args );
			if ( $adzones ) {
				foreach ( $adzones as $adzone ) {
					$ad_zones[ $adzone->ID ] = $adzone->post_title;
				}
			}
			?>
			<p>
				<select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'adzone_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'adzone_id' ) ); ?>">
					<?php $this->print_combobox_options( $ad_zones, $adzone_id ); ?>
				</select>
			</p>
			<?php
		}
	}

	/**
	 * Prints a combobox based on options and selected=match value.
	 *
	 * @since 1.0.0
	 * @param array  $options Array of options.
	 * @param string $selected Which of those options should be selected (allows just one; is case sensitive).
	 */
	public function print_combobox_options( $options, $selected ) {
		foreach ( $options as $key => $value ) {
			echo '<option value="' . esc_html( $key ) . '"';
			if ( $key === (int) $selected ) {
				echo ' selected="selected"';
			}
			echo '>' . esc_html( $value ) . '</option>';
		}
	}
}
