<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://club.wpeka.com/
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/public
 * @author     WPEka Club <support@wpeka.com>
 */
class Wpadcenter_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The location string.
	 *
	 * @access private
	 * @var string $location The location string.
	 */
	private $location;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		if ( ! shortcode_exists( 'wpadcenter' ) ) {
			add_shortcode( 'wpadcenter', array( $this, 'wpadcenter_shortcode' ) );
		}

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0
	 */
	public function enqueue_scripts() {

		/**
		 * An instance of this class should be passed to the run() function
		 * defined in Wpadcenter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpadcenter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_register_script( $this->plugin_name . '-frontend', plugin_dir_url( __FILE__ ) . 'js/wpadcenter-public' . WPADCENTER_SCRIPT_SUFFIX . '.js', array( 'jquery' ), $this->version, true );
	}

	/**
	 * Shortcode display for WPAdCenter.
	 *
	 * @since 1.0.0
	 * @param Array $atts Shortcode attributes.
	 * @return false|string|void
	 */
	public function wpadcenter_shortcode( $atts ) {
		if ( Wpadcenter::is_request( 'admin' ) ) {
			return;
		}
		$atts = shortcode_atts(
			array(
				'id' => 0,
			),
			$atts
		);
		if ( isset( $atts['id'] ) && 0 !== $atts['id'] ) {
			wp_enqueue_script( $this->plugin_name . '-frontend' );
			wp_enqueue_script( $this->plugin_name . '-cycle2' );
			wp_enqueue_style( $this->plugin_name . '-block' );
			wp_localize_script(
				$this->plugin_name . '-frontend',
				'ajax_url',
				array(
					'url'      => admin_url( 'admin-ajax.php' ),
					'security' => wp_create_nonce( 'wpadcenter_set_clicks' ),
				)
			);
			ob_start();
			$container_styles = '';
			$message          = '';
			$adzone_id        = $atts['id'];
			$the_options      = Wpadcenter::wpadcenter_get_settings();
			$geo_location     = $the_options['geo_location'];
			$auto_refresh     = $the_options['auto_refresh'];
			if ( $auto_refresh ) {
				$transition = $the_options['transition_effect'];
				$speed      = $the_options['transition_speed'];
				$delay      = $the_options['transition_delay'];
			}
			$numberofposts     = -1;
			$container_styles .= 'width:100%;height:auto;margin:0;padding:0;';
			$adzone_display    = true;
			if ( 'adzone' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
				$adzone_display = apply_filters( 'wpadcenter_geolocation_adzone', $adzone_id );
			}
			if ( $adzone_display ) {
				$auto_refresh_override = get_field( 'auto_refresh_ads', $adzone_id );
				if ( $auto_refresh_override ) {
					$auto_refresh = $auto_refresh_override;
					$transition   = get_field( 'transition_effect', $adzone_id );
					$speed        = get_field( 'transition_speed', $adzone_id );
					$delay        = get_field( 'transition_delay', $adzone_id );
				}
				$adzone_default_banner = get_field( 'default_banner', $adzone_id );
				$adzone_signup_link    = get_field( 'signup_link', $adzone_id );
				$adzone_template       = get_field( 'template', $adzone_id );
				if ( $adzone_template && '0' !== $adzone_template ) {
					$adzone_size = explode( 'x', $adzone_template );
				} else {
					$adzone_size[0] = get_field( 'custom_width', $adzone_id );
					$adzone_size[1] = get_field( 'custom_height', $adzone_id );
				}
				$adzone_text_above = get_field( 'text_above_ad_zone', $adzone_id );
				$adzone_text_below = get_field( 'text_below_ad_zone', $adzone_id );
				$width             = isset( $adzone_size['0'] ) ? $adzone_size['0'] : '';
				$height            = isset( $adzone_size['1'] ) ? $adzone_size['1'] : '';
				$adzone_rows       = get_field( 'horizontal', $adzone_id );
				$adzone_columns    = get_field( 'vertical', $adzone_id );
				$adzone_classes    = 'adzone_1_1';
				if ( $adzone_rows && $adzone_columns && ! $auto_refresh ) {
					$adzone_classes = 'adzone_' . $adzone_rows . '_' . $adzone_columns;
					$numberofposts  = $adzone_columns * $adzone_rows;
				}
				$args      = array(
					'post_type'   => 'wpadcenter-campaigns',
					'post_status' => 'adc-running',
					'numberposts' => -1,
					'orderby'     => 'rand',
					'order'       => 'ASC',
				);
				$campaigns = get_posts( $args );
				if ( $campaigns ) {
					$campaign_ids = array();
					if ( 'campaign' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
						$campaign_ids = apply_filters( 'wpadcenter_geolocation_campaigns', $campaigns );
					} else {
						foreach ( $campaigns as $campaign ) {
							$campaign_ids[] = $campaign->ID;
						}
					}
					if ( empty( $campaign_ids ) ) {
						$campaign_ids = '';
					}
					$args    = array(
						'post_type'   => 'wpadcenter-banners',
						'post_status' => 'publish',
						'numberposts' => $numberofposts,
						'orderby'     => 'rand',
						'order'       => 'ASC',
						'meta_query'  => array( // phpcs:ignore slow query
							'relation' => 'AND',
							array(
								'key'     => 'banners_campaign',
								'value'   => $campaign_ids,
								'compare' => 'IN',
							),
							array(
								'key'     => 'banners_ad_zone',
								'value'   => $adzone_id,
								'compare' => '=',
							),
						),
					);
					$banners = get_posts( $args );
					if ( $banners ) {
						$message  = apply_filters( 'wpadcenter_block_render_before', $message );
						$message .= '<div class="wpadcenter-text-above">' . $adzone_text_above . '</div>';
						if ( $auto_refresh ) {
							$container_styles .= 'max-width:' . $width . 'px;';
							$message          .= '<div class="wpadcenter-slider cycle-slideshow" data-slides="div.wpadcenter-slide" data-cycle-fx="' . $transition . '" data-cycle-speed="' . $speed . '" data-cycle-delay="' . $delay . '" data-cycle-auto-height="container">';
						} else {
							$message .= '<div class="wpadcenter-slider">';
						}
						foreach ( $banners as $banner ) {
							$banner_id          = $banner->ID;
							$banner_link_url    = get_field( 'link_url', $banner_id );
							$banner_link_target = get_field( 'link_target', $banner_id );
							if ( $banner_link_target && '_blank' !== $banner_link_target && true !== $banner_link_target ) {
								$banner_link_target = '_self';
							} elseif ( $banner_link_target ) {
								$banner_link_target = '_blank';
							} else {
								$banner_link_target = '_self';
							}
							$banner_link_nofollow = get_field( 'link_nofollow', $banner_id );
							$banner_advertiser    = get_field( 'banners_advertiser', $banner_id );
							$banner_campaign      = get_field( 'banners_campaign', $banner_id );
							$banner_ad_zone       = get_field( 'banners_ad_zone', $banner_id );
							$banner_type          = get_field( 'banner_type', $banner_id );
							$message             .= '<div class="wpadcenter-slide ' . $adzone_classes . '">';
							if ( get_option( 'wpadcenter_pro_active' ) ) {
								$message .= '<input type="hidden" name="banner_id" value="' . $banner_id . '">';
								$message .= '<input type="hidden" name="banner_advertiser" value="' . $banner_advertiser . '">';
								$message .= '<input type="hidden" name="banner_campaign" value="' . $banner_campaign . '">';
								$message .= '<input type="hidden" name="banner_ad_zone" value="' . $banner_ad_zone . '">';
								if ( get_option( 'wpadcenter_pro_active' ) ) {
									Wpadcenter::wpadcenter_set_impressions( $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone );
								}
							}
							$message .= '<a class="link" href="' . $banner_link_url . '" target="' . $banner_link_target . '"';
							if ( $banner_link_nofollow ) {
								$message .= ' rel="nofollow"';
							}
							$message .= '>';
							switch ( $banner_type ) {
								case 'image':
									$banner_img = get_field( 'image', $banner_id );
									$banner_img = wp_get_attachment_image( $banner_img, $width, $height );
									$message   .= $banner_img;
									break;
								case 'external_image_link':
									$banner_img_link = get_field( 'image_link', $banner_id );
									$message        .= '<img width="' . $width . '" height="' . $height . '" src="' . esc_url( $banner_img_link ) . '"/>';
									break;
								case 'ad_code':
									$banner_ad_code = get_field( 'ad_code', $banner_id );
									$message       .= '<span class="wpadcenter-ad-code">' . $banner_ad_code . '</span>';
									break;
								case 'adsense_code':
									$banner_ad_code = get_field( 'field_google_adsense_code', $banner_id );
									$message       .= '<div style="min-height:200px;min-width: 200px" class="wpadcenter-ad-code">' . $banner_ad_code . '</div>';
									break;

							}
							$message .= '</a>';
							$message .= '</div>';
						}
						$message .= '</div>';
						$message .= '<div class="wpadcenter-text-below">' . $adzone_text_below . '</div>';
					} else {
						if ( $adzone_default_banner ) {
							$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
							$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
							$message           .= $default_banner_img;
							$message           .= '</a>';
						}
					}
				} else {
					if ( $adzone_default_banner ) {
						$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
						$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
						$message           .= $default_banner_img;
						$message           .= '</a>';
					}
				}
			}
			?>
			<div class="wpadcenter-block-container" style="<?php echo $container_styles; ?>"><?php echo $message; ?></div> <?php // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<?php
			return ob_get_clean();
		}
	}

	/**
	 * Set clicks for campaign statistics.
	 */
	public function wpadcenter_set_clicks() {
		global $wpdb;
		$response = array(
			'success' => true,
		);
		if ( get_option( 'wpadcenter_pro_active' ) ) {
			if ( isset( $_POST['action'] ) ) {
				$security = isset( $_POST['security'] ) ? sanitize_text_field( wp_unslash( $_POST['security'] ) ) : '';
				if ( wp_verify_nonce( $security, 'wpadcenter_set_clicks' ) ) {
					if ( isset( $_POST['data'] ) && ! empty( $_POST['data'] ) ) {
						$banner_id         = isset( $_POST['data']['banner_id'] ) ? sanitize_text_field( wp_unslash( $_POST['data']['banner_id'] ) ) : 0;
						$banner_advertiser = isset( $_POST['data']['banner_advertiser'] ) ? sanitize_text_field( wp_unslash( $_POST['data']['banner_advertiser'] ) ) : 0;
						$banner_campaign   = isset( $_POST['data']['banner_campaign'] ) ? sanitize_text_field( wp_unslash( $_POST['data']['banner_campaign'] ) ) : 0;
						$banner_ad_zone    = isset( $_POST['data']['banner_ad_zone'] ) ? sanitize_text_field( wp_unslash( $_POST['data']['banner_ad_zone'] ) ) : 0;

						$today   = gmdate( 'Y-m-d' );
						$records = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'adc_statistics WHERE banner_id = %d AND campaign_id = %d AND advertiser_id = %d AND adzone_id = %d AND date = %s LIMIT 1', array( $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone, $today ) ), ARRAY_A ); // db call ok; no-cache ok.
						if ( count( $records ) ) {
							$record = $records[0];
							$clicks = $record['clicks'] + 1;
							$wpdb->query( $wpdb->prepare( 'UPDATE ' . $wpdb->prefix . 'adc_statistics SET clicks = %d WHERE banner_id = %d AND campaign_id = %d AND advertiser_id = %d AND adzone_id = %d AND date = %s', array( $clicks, $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone, $today ) ) ); // db call ok; no-cache ok.
							do_action( 'wpadcenter_after_set_clicks', $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone, $clicks );
						} else {
							$wpdb->query( $wpdb->prepare( 'INSERT IGNORE INTO `' . $wpdb->prefix . 'adc_statistics` (`banner_id`,`campaign_id`,`advertiser_id`, `adzone_id`, `clicks`, `date`) VALUES (%d,%d,%d,%d,%d,%s)', array( $banner_id, $banner_campaign, $banner_advertiser, $banner_ad_zone, 1, $today ) ) ); // db call ok; no-cache ok.
						}
					}
				}
			}
		}
		echo wp_json_encode( $response );
		exit;
	}

	/**
	 * Ads.txt file frontend output.
	 */
	public function wpadcenter_init() {
		if ( isset( $_SERVER['REQUEST_URI'] ) && '/ads.txt' === $_SERVER['REQUEST_URI'] ) { // phpcs:ignore input var ok, CSRF ok, sanitization ok.
			if ( is_multisite() ) {
				global $current_blog;
				$domain = $current_blog->domain;
				// Get all sites that include the current domain as part of their domains.
				$sites = get_sites(
					array(
						'search'         => $domain,
						'search_columns' => array( 'domain' ),
					)
				);
				// Uses `subdomain=` variable.
				$referrals = array();
				// Included to the ads.txt file of the current domain.
				$not_refferals = array();

				foreach ( $sites as $site ) {
					if ( get_current_blog_id() === (int) $site->blog_id ) {
						// Current domain, no need to refer.
						$not_refferals[] = $site->blog_id;
						continue;
					}

					if ( $this->wpadcenter_get_root_domain_info() ) {
						// Subdomains cannot refer to other subdomains.
						$not_refferals[] = $site->blog_id;
						continue;
					}

					if ( '/' !== $site->path ) {
						// We can refer to domains, not domains plus path.
						$not_refferals[] = $site->blog_id;
						continue;
					}

					$referrals[ $site->blog_id ] = $site->domain;
				}
				$content = '';
				if ( ! empty( $not_refferals ) ) {
					foreach ( $not_refferals as $blog_id ) {
						$the_options   = get_blog_option( $blog_id, WPADCENTER_SETTINGS_FIELD );
						$plugin_active = get_blog_option( $blog_id, 'wpadcenter_active' );
						if ( $the_options['enable_ads_txt'] && $plugin_active ) {
							$content .= '# blog_id : ' . $blog_id . "\n";
							$content .= $the_options['ads_txt_content'] . "\n";
							if ( get_current_blog_id() === $blog_id ) {
								// Refer to other subdomains.
								foreach ( $referrals  as $blog_id => $referral ) {
									$content .= '# refer to blog_id : ' . $blog_id . "\nsubdomain=" . $referral . "\n";
								}
							}
						}
					}
				}
			} else {
				$the_options = Wpadcenter::wpadcenter_get_settings();
				if ( $the_options['enable_ads_txt'] ) {
					$content = $the_options['ads_txt_content'];
				}
			}
			if ( isset( $content ) && ! empty( $content ) ) {
				header( 'Content-Type: text/plain; charset=utf-8' );
				$content = Wpadcenter::TOP . "\n" . $content;
				$content = esc_html( $content );
				echo $content; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				exit;
			}
		}
	}

	/**
	 * Get root domain info.
	 *
	 * @param null $url URL.
	 * @return bool
	 */
	public function wpadcenter_get_root_domain_info( $url = null ) {
		$url        = $url ? $url : home_url( '/' );
		$parsed_url = wp_parse_url( $url );
		if ( ! isset( $parsed_url['host'] ) ) {
			return false;
		}
		$host = $parsed_url['host'];
		if ( WP_Http::is_ip_address( $host ) ) {
			return false;
		}
		$host_parts = explode( '.', $host );
		$count      = count( $host_parts );
		if ( $count < 3 ) {
			return false;
		}
		if ( 3 === $count ) {
			// Example: `http://one.{net/org/gov/edu/co}.two`.
			$suffixes = array( 'net', 'org', 'gov', 'edu', 'co' );
			if ( in_array( $host_parts[ $count - 2 ], $suffixes, true ) ) {
				return false;
			}
			// Example: `one.com.au'.
			$suffix_and_tld = implode( '.', array_slice( $host_parts, 1 ) );
			if ( in_array( $suffix_and_tld, array( 'com.au', 'com.br', 'com.pl' ), true ) ) {
				return false;
			}
			// `http://www.one.two` will only be crawled if `http://one.two` redirects to it.
			// Check if such redirect exists.
			if ( 'www' === $host_parts[0] ) {
				/*
				 * Do not append `/ads.txt` because otherwise the redirect will not happen.
				 */
				$no_www_url = $parsed_url['scheme'] . '://' . trailingslashit( $host_parts[1] . '.' . $host_parts[2] );

				add_action( 'requests-requests.before_redirect', array( $this, 'collect_locations' ) );
				wp_remote_get(
					$no_www_url,
					array(
						'timeout'     => 5,
						'redirection' => 3,
					)
				);
				remove_action( 'requests-requests.before_redirect', array( $this, 'collect_locations' ) );

				$no_www_url_parsed = wp_parse_url( $this->location );
				if ( isset( $no_www_url_parsed['host'] ) && $no_www_url_parsed['host'] === $host ) {
					return false;
				}
			}
		}
		return true;
	}

	/**
	 * Location string.
	 *
	 * @param string $location Location string.
	 */
	public function wpadcenter_collect_locations( $location ) {
		$this->location = $location;
	}

	/**
	 * Template redirect for header, body and footer scripts.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_template_redirect() {
		global $post;
		$the_options = Wpadcenter::wpadcenter_get_settings();

		if ( is_admin() || defined( 'DOING_AJAX' ) || defined( 'DOING_CRON' ) || ! $the_options['enable_scripts'] ) {
			return;
		}

		$body_open_supported = function_exists( 'wp_body_open' ) && version_compare( get_bloginfo( 'version' ), '5.2', '>=' );

		if ( is_singular() && $post ) {
			$disable_global_scripts = get_field( 'disable_global_scripts', $post->ID );

			add_action( 'wp_head', array( $this, 'wpadcenter_output_header_post' ) );
			if ( $body_open_supported ) {
				add_action( 'wp_body_open', array( $this, 'wpadcenter_output_body_post' ) );
			}
			add_action( 'wp_footer', array( $this, 'wpadcenter_output_footer_post' ) );

			if ( ! $disable_global_scripts ) {
				add_action( 'wp_head', array( $this, 'wpadcenter_output_header_global' ) );
				if ( $body_open_supported ) {
					add_action( 'wp_body_open', array( $this, 'wpadcenter_output_body_global' ) );
				}
				add_action( 'wp_footer', array( $this, 'wpadcenter_output_footer_global' ) );
			}
		}

		if ( is_home() ) {
			add_action( 'wp_head', array( $this, 'wpadcenter_output_header_global' ) );
			if ( $body_open_supported ) {
				add_action( 'wp_body_open', array( $this, 'wpadcenter_output_body_global' ) );
			}
			add_action( 'wp_footer', array( $this, 'wpadcenter_output_footer_global' ) );
		}
	}

	/**
	 * Output header scripts for post.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_header_post() {
		global $post;
		$header_scripts = get_field( 'header_scripts', $post->ID );
		if ( $header_scripts ) {
			echo "\r\n" . $header_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Output body scripts for post.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_body_post() {
		global $post;
		$body_scripts = get_field( 'body_scripts', $post->ID );
		if ( $body_scripts ) {
			echo "\r\n" . $body_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Output footer scripts for post.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_footer_post() {
		global $post;
		$footer_scripts = get_field( 'footer_scripts', $post->ID );
		if ( $footer_scripts ) {
			echo "\r\n" . $footer_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Output global header scripts.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_header_global() {
		$the_options    = Wpadcenter::wpadcenter_get_settings();
		$header_scripts = $the_options['header_scripts'];
		if ( $header_scripts ) {
			echo "\r\n" . $header_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Output global body scripts.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_body_global() {
		$the_options  = Wpadcenter::wpadcenter_get_settings();
		$body_scripts = $the_options['body_scripts'];
		if ( $body_scripts ) {
			echo "\r\n" . $body_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	/**
	 * Output global footer scripts.
	 *
	 * @since 1.0.1
	 */
	public function wpadcenter_output_footer_global() {
		$the_options    = Wpadcenter::wpadcenter_get_settings();
		$footer_scripts = $the_options['footer_scripts'];
		if ( $footer_scripts ) {
			echo "\r\n" . $footer_scripts . "\r\n"; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

}
